==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/templatecolumn.js <==
joo.classLoader.prepare("package ext.config",/* {*/

/**
 * A Column definition class which renders a value by processing a <a href="Ext.data.Record.html">Record</a>'s <a href="output/Ext.data.Record.html#Ext.data.Record-data">data</a> using a <a href="output/Ext.grid.TemplateColumn.html#Ext.grid.TemplateColumn-tpl">configured</a> <a href="Ext.XTemplate.html">XTemplate</a>. See the <a href="output/Ext.grid.Column.html#Ext.grid.Column-xtype">xtype</a> config option of <a href="Ext.grid.Column.html">Ext.grid.Column</a> for more details.

 *
 * <p>This class serves as a
 * typed config object for constructor of class TemplateColumn.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.TemplateColumn
 */
{ExtConfig:{target:"ext.grid.TemplateColumn", gctype:"templatecolumn"}},
"public class templatecolumn extends ext.config.gridcolumn",3,function($$private){;return[ 

  "public function templatecolumn",function templatecolumn$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    ext.config.gridcolumn.call(this,config);
  },


  /**
   An <a href="Ext.XTemplate.html">XTemplate</a>, or an XTemplate <i>definition string</i> to use to process a <a href="Ext.data.Record.html">Record</a>'s <a href="output/Ext.data.Record.html#Ext.data.Record-data">data</a> to produce a column's rendered value.
   */
  "public native function get tpl"/*():**/,

  /**
   * @private
   */
  "public native function set tpl"/*(value:*):void*/,


];},[],["ext.config.gridcolumn"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/templatecolumn.js <==
joo.classLoader.prepare("package ext.config",/* {*/

/**
 * A Column definition class which renders a value by processing a <a href="Ext.data.Record.html">Record</a>'s <a href="output/Ext.data.Record.html#Ext.data.Record-data">data</a> using a <a href="output/Ext.grid.TemplateColumn.html#Ext.grid.TemplateColumn-tpl">configured</a> <a href="Ext.XTemplate.html">XTemplate</a>. See the <a href="output/Ext.grid.Column.html#Ext.grid.Column-xtype">xtype</a> config option of <a href="Ext.grid.Column.html">Ext.grid.Column</a> for more details.

 *
 * <p>This class serves as a
 * typed config object for constructor of class TemplateColumn.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.TemplateColumn
 */
{ExtConfig:{target:"ext.grid.TemplateColumn", gctype:"templatecolumn"}},
"public class templatecolumn extends ext.config.gridcolumn",3,function($$private){var $1=ext.config;return[ 

  "public function templatecolumn",function templatecolumn(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.gridcolumn.call(this,config);
  },


  /**
   An <a href="Ext.XTemplate.html">XTemplate</a>, or an XTemplate <i>definition string</i> to use to process a <a href="Ext.data.Record.html">Record</a>'s <a href="output/Ext.data.Record.html#Ext.data.Record-data">data</a> to produce a column's rendered value.
   */
  "public native function get tpl"/*():**/,

  /**
   * @private
   */
  "public native function set tpl"/*(value:*):void*/,


undefined];},[],["ext.config.gridcolumn"], "0.8.0", "0.9.12"
);
